@@ -1,6 +1,6 @@
 /* GNU Datamash - perform simple calculation on input data
 
-   Copyright (C) 2013-2018 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2013-2019 Assaf Gordon <assafgordon@gmail.com>
 
    This file is part of GNU Datamash.
 
@@ -55,8 +55,8 @@
 #include "column-headers.h"
 #include "op-defs.h"
 #include "op-parser.h"
-#include "field-ops.h"
 #include "utils.h"
+#include "field-ops.h"
 #include "crosstab.h"
 
 /* The official name of this program (e.g., no 'g' prefix).  */
@@ -196,7 +196,8 @@ which require a pair of fields (e.g. 'pcov 2:6').\n"), stdout);
 
       fputs (_("Per-Line operations:\n"),stdout);
       fputs ("  base64, debase64, md5, sha1, sha256, sha512,\n", stdout);
-      fputs ("  bin, strbin, round, floor, ceil, trunc, frac\n", stdout);
+      fputs ("  bin, strbin, round, floor, ceil, trunc, frac,\n", stdout);
+      fputs ("  dirname, basename, barename, extname, getnum, cut\n", stdout);
 
       fputs (_("Numeric Grouping operations:\n"),stdout);
       fputs ("  sum, min, max, absmin, absmax, range\n",stdout);
