@@ -1,6 +1,6 @@
 /* GNU Datamash - perform simple calculation on input data
 
-   Copyright (C) 2013-2018 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2013-2019 Assaf Gordon <assafgordon@gmail.com>
 
    This file is part of GNU Datamash.
 
@@ -31,6 +31,7 @@
 #include <string.h>
 #include <stdbool.h>
 #include <time.h>
+#include <libgen.h> /* for dirname & POSIX version of basename */
 
 #include "die.h"
 #include "minmax.h"
@@ -155,6 +156,18 @@ struct operation_data operations[] =
   {NUMERIC_SCALAR, IGNORE_FIRST, NUMERIC_RESULT},
   /* OP_TRIMMED_MEAN */
   {NUMERIC_SCALAR, IGNORE_FIRST, NUMERIC_RESULT},
+  /* OP_DIRNAME */
+  {STRING_SCALAR, IGNORE_FIRST, STRING_RESULT},
+  /* OP_BASENAME */
+  {STRING_SCALAR, IGNORE_FIRST, STRING_RESULT},
+  /* OP_EXTNAME */
+  {STRING_SCALAR, IGNORE_FIRST, STRING_RESULT},
+  /* OP_BARENAME */
+  {STRING_SCALAR, IGNORE_FIRST, STRING_RESULT},
+  /* OP_GETNUM */
+  {STRING_SCALAR, IGNORE_FIRST, NUMERIC_RESULT},
+  /* OP_CUT */
+  {STRING_SCALAR, IGNORE_FIRST, STRING_RESULT},
   {0, 0, NUMERIC_RESULT}
 };
 
@@ -468,6 +481,10 @@ field_op_collect (struct fieldop *op,
     case OP_SHA1:
     case OP_SHA256:
     case OP_SHA512:
+    case OP_DIRNAME:
+    case OP_BASENAME:
+    case OP_EXTNAME:
+    case OP_BARENAME:
       /* Replace the 'current' string with the latest one */
       field_op_replace_string (op, str, slen);
       break;
@@ -557,6 +574,14 @@ field_op_collect (struct fieldop *op,
       };
       break;
 
+    case OP_GETNUM:
+      op->value = extract_number (str, slen, op->params.get_num_type);
+      break;
+
+    case OP_CUT:
+      field_op_replace_string (op, str, slen);
+      break;
+
     case OP_INVALID:                 /* LCOV_EXCL_LINE */
     default:                         /* LCOV_EXCL_LINE */
       /* Should never happen */
@@ -696,6 +721,7 @@ field_op_summarize_empty (struct fieldop *op)
     case OP_FRACTION:
     case OP_RANGE:
     case OP_TRIMMED_MEAN:
+    case OP_GETNUM:
       numeric_result = nanl ("");
       break;
 
@@ -718,6 +744,7 @@ field_op_summarize_empty (struct fieldop *op)
     case OP_FIRST:
     case OP_LAST:
     case OP_RAND:
+    case OP_CUT:
       field_op_reserve_out_buf (op, 4);
       strcpy (op->out_buf, "N/A");
       break;
@@ -730,6 +757,10 @@ field_op_summarize_empty (struct fieldop *op)
     case OP_SHA1:
     case OP_SHA256:
     case OP_SHA512:
+    case OP_DIRNAME:
+    case OP_BASENAME:
+    case OP_EXTNAME:
+    case OP_BARENAME:
       field_op_reserve_out_buf (op, 1);
       strcpy (op->out_buf, "");
       break;
@@ -783,6 +814,7 @@ field_op_summarize (struct fieldop *op)
     case OP_ROUND:
     case OP_TRUNCATE:
     case OP_FRACTION:
+    case OP_GETNUM:
       /* no summarization for these operations, just print the value */
       numeric_result = op->value;
       break;
@@ -790,6 +822,7 @@ field_op_summarize (struct fieldop *op)
     case OP_FIRST:
     case OP_LAST:
     case OP_RAND:
+    case OP_CUT:
       /* Only one string is returned in the buffer, return it */
       field_op_reserve_out_buf (op, op->str_buf_used);
       memcpy (op->out_buf, op->str_buf, op->str_buf_used);
@@ -962,6 +995,65 @@ field_op_summarize (struct fieldop *op)
       field_op_to_hex (op, tmpbuf, 64);
       break;
 
+    case OP_DIRNAME:
+      {
+        op->str_buf[op->str_buf_used] = 0;
+        char *t = dirname (op->str_buf);
+        field_op_reserve_out_buf (op, op->str_buf_used);
+        strcpy (op->out_buf,t);
+      }
+      break;
+
+    case OP_BASENAME:
+    case OP_EXTNAME:
+    case OP_BARENAME:
+      {
+        if (op->str_buf_used==1)
+          {
+            /* Empty string, containing only NUL */
+            field_op_reserve_out_buf (op, 1);
+            op->out_buf[0] = '\0';
+            break;
+          }
+
+        op->str_buf[op->str_buf_used] = 0;
+        char *t = basename (op->str_buf);
+        field_op_reserve_out_buf (op, op->str_buf_used);
+
+        if (op->op == OP_BASENAME)
+          {
+            /* Just copy the extracted base name */
+            strcpy (op->out_buf,t);
+          }
+        else
+          {
+            /* Guess the file extension */
+            size_t tl = strlen (t);
+            size_t l = guess_file_extension (t, tl);
+
+            if (op->op == OP_EXTNAME)
+              {
+                /* Store the extension */
+                if (l>0)
+                  {
+                    memcpy (op->out_buf, t+(tl-l+1), l-1);
+                    op->out_buf[l-1] = '\0';
+                  }
+                else
+                  {
+                    op->out_buf[0] = '\0';
+                  }
+              }
+            else
+              {
+                /* Store the basename without the extension */
+                memcpy (op->out_buf, t, tl-l);
+                op->out_buf[tl-l] = '\0';
+              }
+          }
+      }
+      break;
+
     case OP_INVALID:                 /* LCOV_EXCL_LINE */
     default:                         /* LCOV_EXCL_LINE */
       /* Should never happen */
