@@ -1,6 +1,6 @@
 /* GNU Datamash - perform simple calculation on input data
 
-   Copyright (C) 2013-2018 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2013-2019 Assaf Gordon <assafgordon@gmail.com>
 
    This file is part of GNU Datamash.
 
@@ -74,6 +74,10 @@ struct field_operation_definition field_operations[] =
   {"sha1",    OP_SHA1,    MODE_PER_LINE},
   {"sha256",  OP_SHA256,  MODE_PER_LINE},
   {"sha512",  OP_SHA512,  MODE_PER_LINE},
+  {"dirname", OP_DIRNAME, MODE_PER_LINE},
+  {"basename",OP_BASENAME,MODE_PER_LINE},
+  {"extname", OP_EXTNAME, MODE_PER_LINE},
+  {"barename",OP_BARENAME,MODE_PER_LINE},
   {"pcov",    OP_P_COVARIANCE, MODE_GROUPBY},
   {"scov",    OP_S_COVARIANCE, MODE_GROUPBY},
   {"ppearson",OP_P_PEARSON_COR, MODE_GROUPBY},
@@ -86,6 +90,8 @@ struct field_operation_definition field_operations[] =
   {"trunc",   OP_TRUNCATE,   MODE_PER_LINE},
   {"frac",    OP_FRACTION,   MODE_PER_LINE},
   {"trimmean",OP_TRIMMED_MEAN,   MODE_GROUPBY},
+  {"getnum",  OP_GETNUM,   MODE_PER_LINE},
+  {"cut",     OP_CUT,     MODE_PER_LINE},
   {NULL,      OP_INVALID, MODE_INVALID}
 };
 
