@@ -1,6 +1,6 @@
 /* GNU Datamash - perform simple calculation on input data
 
-   Copyright (C) 2013-2018 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2013-2019 Assaf Gordon <assafgordon@gmail.com>
 
    This file is part of GNU Datamash.
 
@@ -76,7 +76,13 @@ enum field_operation
   OP_ROUND,         /* Round */
   OP_TRUNCATE,      /* Truncate */
   OP_FRACTION,      /* Fraction */
-  OP_TRIMMED_MEAN   /* Trimmed Mean */
+  OP_TRIMMED_MEAN,  /* Trimmed Mean */
+  OP_DIRNAME,       /* like dirname (1) */
+  OP_BASENAME,      /* like basename (1) */
+  OP_EXTNAME,       /* guess extension of file name */
+  OP_BARENAME,      /* like basename without the guessed extension  */
+  OP_GETNUM,        /* Extract a number from a string */
+  OP_CUT            /* like cut (1) */
 };
 
 enum processing_mode
