@@ -1,6 +1,6 @@
 /* GNU Datamash - perform simple calculation on input data
 
-   Copyright (C) 2013-2018 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2013-2019 Assaf Gordon <assafgordon@gmail.com>
 
    This file is part of GNU Datamash.
 
@@ -63,7 +63,7 @@ extern bool strict;
 extern char* missing_field_filler;
 
 /* if true, skip comments line (lines starting with optional whitespace
-   followed by '#' or ';'. See line_record_is_comment().  */
+   followed by '#' or ';'. See line_record_is_comment.  */
 extern bool skip_comments;
 
 #define UCHAR_LIM (UCHAR_MAX + 1)
