@@ -1,6 +1,6 @@
 /* GNU Datamash - perform simple calculation on input data
 
-   Copyright (C) 2013-2018 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2013-2019 Assaf Gordon <assafgordon@gmail.com>
 
    This file is part of GNU Datamash.
 
@@ -381,7 +381,7 @@ mode_value ( const long double * const values, size_t n, enum MODETYPE type)
   long double last_value = values[0];
   size_t seq_size=1;
   size_t best_seq_size= (type==MODE)?1:SIZE_MAX;
-  size_t best_value = values[0];
+  long double best_value = values[0];
 
   for (size_t i=1; i<n; i++)
     {
@@ -458,3 +458,137 @@ hash_compare_strings (void const *x, void const *y)
   assert (x != y); /* LCOV_EXCL_LINE */
   return STREQ (x, y) ? true : false;
 }
+
+
+static bool
+is_add_on_extension (const char *s, size_t l)
+{
+  if ((l==4) \
+      && (STREQ_LEN(s,".gpg",4) \
+          || STREQ_LEN(s,".bz2",4) \
+          || STREQ_LEN(s,".std",4)))
+    return true;
+  if ((l==3) \
+      && (STREQ_LEN(s,".gz",3) || STREQ_LEN(s,".xz",3) || STREQ_LEN(s,".lz",3)))
+    return true;
+  return false;
+}
+
+size_t _GL_ATTRIBUTE_PURE
+guess_file_extension (const char*s, size_t len)
+{
+  size_t prev_extension = 0;
+
+  if (len==0)
+    return 0;
+
+  size_t l = len - 1 ;
+
+ next_extension:
+  while (l && c_isalnum (s[l]))
+    --l;
+  if (l>0 && s[l] == '.')
+    {
+      /* Found an extension, check if it's a known "add-on" one */
+
+      /* check the string until to previous extension (if there was one),
+         or the end of the string. */
+      size_t ext_len = (prev_extension==0)?(len-l):(prev_extension-l);
+      if (is_add_on_extension (&s[l],ext_len))
+        {
+          prev_extension = l;
+          --l;
+          goto next_extension;
+        }
+
+      return len-l;
+    }
+
+  /* In a case such as "foo.gpg", the first detected extension '.gpg'
+     is found, but the second iteration fails (as 'foo' is not an extension).
+     In such cases, revert to reporting the previously found extension. */
+  if (prev_extension)
+    return len-prev_extension;
+
+  return 0;
+}
+
+
+struct EXTRACT_NUMBER_TYPE
+{
+  char *pattern;
+  int base;
+  bool floating_point;
+};
+
+/* NOTE: order must match 'enum extract_number_type' */
+static struct EXTRACT_NUMBER_TYPE extract_number_types[] =
+  {
+   /* Natural Number (nonnegative integers), including ZERO */
+   {"0123456789", 10,  false},
+
+   /* Integers */
+   {"-+0123456789", 10, false},
+
+   /* Positive Hex number */
+   {"0123456789abcdefABCDEF", 16, false},
+
+   /* Positive Octal number */
+   {"01234567", 8, false},
+
+   /* Simple positive decimal point (including zero) */
+   {".01234567", 10, true},
+
+   /* Simple decimal point (positive and negative) */
+   {"+-.01234567", 10, true}
+  };
+
+
+long double
+extract_number (const char* s, size_t len, enum extract_number_type type)
+{
+  static char* buf, *endptr;
+  static size_t buf_alloc;
+
+  long double r = 0;
+  char *pattern;
+  int base ;
+  bool fp;
+
+  pattern = extract_number_types[type].pattern;
+  base = extract_number_types[type].base;
+  fp = extract_number_types[type].floating_point;
+
+  if (len+1 > buf_alloc)
+    {
+      buf = xrealloc (buf, len+1);
+      buf_alloc = len + 1;
+    }
+
+  size_t skip = strcspn (s, pattern);
+  size_t span = strspn (s+skip, pattern);
+
+  memcpy (buf, s+skip, span);
+  buf[span] = '\0';
+
+  if (!fp)
+    {
+      errno = 0;
+      long long int val = strtoll (buf, &endptr, base);
+      if (errno != 0)
+        {
+          /* failed to parse value */
+          val = 0;
+        }
+      r = val;
+    }
+  else
+    {
+      errno = 0;
+      r = strtold (buf, &endptr);
+      if (errno != 0)
+        r = 0;
+    }
+
+  return r;
+}
