@@ -1,6 +1,6 @@
 /* GNU Datamash - perform simple calculation on input data
 
-   Copyright (C) 2013-2018 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2013-2019 Assaf Gordon <assafgordon@gmail.com>
 
    This file is part of GNU Datamash.
 
@@ -205,6 +205,32 @@ cmp_long_double (const void *p1, const void *p2);
 bool
 hash_compare_strings (void const *x, void const *y);
 
+
+/* Return the number of characters FROM THE END of 's'
+   that match a guessed file extension.
+   Return 0 if no extension is found.
+   's' does not need to be NULL terminated. */
+size_t
+guess_file_extension (const char*s, size_t len);
+
+
+/* Extract the first detected number from a string 's'
+   (skipping non-number characters).
+   's' does not need to be NUL-terminated. */
+enum extract_number_type
+  {
+   ENT_NATURAL = 0,
+   ENT_INTEGER,
+   ENT_HEX,
+   ENT_OCT,
+   ENT_POSITIVE_DECIMAL,
+   ENT_DECIMAL
+  };
+long double
+extract_number (const char* s, size_t len, enum extract_number_type type);
+
+
+
 /* returns non-zero if the input is equavalent to
    zero (or negative zero) */
 static inline bool
@@ -228,6 +254,7 @@ pos_zero (const long double a)
   return is_signed_zero (a) ? 0 : a;
 }
 
+
 /* On some systems (e.g. Cygwin) nanl is not defined,
    and gnulib does not yet provide a replacment
    (though it does provide 'isnanl' replacement) */
