@@ -2,7 +2,7 @@
 =pod
   Unit Tests for GNU Datamash - perform simple calculation on input data
 
-   Copyright (C) 2013-2018 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2013-2019 Assaf Gordon <assafgordon@gmail.com>
 
    This file is part of GNU Datamash.
 
@@ -299,6 +299,79 @@ bar	5
 ;baz	7
 EOF
 
+my $in_esc_ident=<<'EOF';
+A_Chlor_T1h_r1-metaG B 9C -bar
+1 2 3 4
+10 20 30 40
+EOF
+
+#
+my $in_dirname_basename=<<'EOF';
+/foo/bar
+/foo/
+foo
+/
+.
+..
+	
+EOF
+
+my $exp_dirname_basename=<<'EOF';
+/foo	bar
+/	foo
+.	foo
+/	/
+.	.
+.	..
+.	
+EOF
+
+my $in_barename_extname=<<'EOF';
+hello-world.txt
+hello.world.txt
+.hello
+.txt
+foo%bar
+foo
+foo.tar.gz
+foo.txt.std
+foo.org.lz
+foo.a3
+foo.gpg
+foo.txt.xz.gpg
+foo.log.bz2
+foo.bar
+foo.bloo
+foo.bar.txt.log
+	
+EOF
+
+my $exp_barename_extname=<<'EOF';
+hello-world	txt
+hello.world	txt
+.hello	
+.txt	
+foo%bar	
+foo	
+foo	tar.gz
+foo	txt.std
+foo	org.lz
+foo	a3
+foo	gpg
+foo	txt.xz.gpg
+foo	log.bz2
+foo	bar
+foo	bloo
+foo.bar.txt	log
+	
+EOF
+
+my $in1_cut=<<'EOF';
+a,b,c
+1,X,6
+EOF
+
+
 
 my @Tests =
 (
@@ -515,6 +588,67 @@ my @Tests =
 	 "5	bar\n" .
 	 "7	;baz\n"}],
   ['sc4', '-C reverse', {IN_PIPE=>$in_comments}, {OUT=>"5	bar\n"}],
+
+
+  # Bug in mode/antimode in 1.4 and earlier
+  ['bug_mode1', 'mode 1', {IN_PIPE=>"-1"}, {OUT=>"-1\n"}],
+
+  ##
+  ## Backslash escaping in identifiers
+  ##
+
+  ## minus in field name
+  ['esc1', '-W -H sum "A_Chlor_T1h_r1\\-metaG"', {IN_PIPE=>$in_esc_ident},
+     {OUT=>"sum(A_Chlor_T1h_r1-metaG)\n11\n"}],
+  # field name starting with an identifier
+  ['esc2', '-W -H sum "\\9C"', {IN_PIPE=>$in_esc_ident},
+   {OUT=>"sum(9C)\n33\n"}],
+  # field name starting with minus
+  ['esc3', '-W -H sum "\\-bar"', {IN_PIPE=>$in_esc_ident},
+     {OUT=>"sum(-bar)\n44\n"}],
+
+
+  # dirname and basename
+  ['dnbn1', 'dirname 1 basename 1', {IN_PIPE=>$in_dirname_basename},
+     {OUT=>$exp_dirname_basename}],
+
+  # barename and extname
+  ['bnen1', 'barename 1 extname 1', {IN_PIPE=>$in_barename_extname},
+     {OUT=>$exp_barename_extname}],
+
+
+
+  ## GetNum variants
+  ['gn1', 'getnum 1',   {IN_PIPE=>"moo-123.45"}, {OUT=>"123.45\n"}],
+  # Integer
+  ['gn2', 'getnum:i 1', {IN_PIPE=>"moo-123.45"}, {OUT=>"-123\n"}],
+  # Hex 0x123 = 291
+  ['gn3', 'getnum:h 1', {IN_PIPE=>"moo-123.45"}, {OUT=>"291\n"}],
+  # Octal 0123 = 83
+  ['gn4', 'getnum:o 1', {IN_PIPE=>"moo-123.45"}, {OUT=>"83\n"}],
+  # Natural
+  ['gn5', 'getnum:n 1', {IN_PIPE=>"moo-123.45"}, {OUT=>"123\n"}],
+  # Decimal
+  ['gn6', 'getnum:d 1', {IN_PIPE=>"moo-123.45"}, {OUT=>"-123.45\n"}],
+
+  ['gn10', 'getnum 1',   {IN_PIPE=>"moo"},     {OUT=>"0\n"}],
+  ['gn11', 'getnum:d 1', {IN_PIPE=>"moo"},     {OUT=>"0\n"}],
+  ['gn12', 'getnum:i 1', {IN_PIPE=>"moo---4"}, {OUT=>"0\n"}],
+  ['gn13', 'getnum:d 1', {IN_PIPE=>"moo...4"}, {OUT=>"0\n"}],
+  ['gn14', 'getnum:i 1',
+   {IN_PIPE=>"moo999999999999999999999999999991234312341432123451541341312431"},
+   {OUT=>"0\n"}],
+  ['gn15', 'getnum:d 1',
+   {IN_PIPE=>"moo" . 9 x "3000"},
+   {OUT=>"0\n"}],
+  ['gn16', 'getnum:n 1', {IN_PIPE=>"moo" x 4000 . "42" . "bar" x 1000},
+   {OUT=>"42\n"}],
+
+
+  # cut operation
+  ['cut1','-t, cut 3,1,2', {IN_PIPE=>$in1_cut}, {OUT=>"c,a,b\n6,1,X\n"}],
+  ['cut2','-t, -H cut c,a', {IN_PIPE=>$in1_cut}, {OUT=>"cut(c),cut(a)\n6,1\n"}],
+
 );
 
 
